@@ -1,5 +1,11 @@
-exportBed <- function(x, file, header=FALSE){
+exportBed <- function(x, file=NULL, header=FALSE){
 
+  if(is.null(file)){
+    file <- deparse(substitute(x))
+    file <- paste(file,".bed",sep="")
+    cat("No file name (option: 'file') given, use the variable name instead:", file, "\n")  
+  }
+  
   if(header){
     cat("write out the bed-file, using the following column names:\n")
     cat(colnames(x))
